@@ -52,7 +52,7 @@ class AbstractConnection(Generic[Node]):
     node: Node
     message_tracker: Optional[MessageTracker]
 
-    def __init__(self, socket_connection: AbstractSocketConnectionProtocol, node: Node):
+    def __init__(self, socket_connection: AbstractSocketConnectionProtocol, node: Node) -> None:
         self.socket_connection = socket_connection
         self.file_no = socket_connection.file_no
 
@@ -82,6 +82,7 @@ class AbstractConnection(Generic[Node]):
         self.peer_desc = repr(self.endpoint)
 
         self.can_send_pings = False
+        self.pong_timeout_enabled = False
 
         self.hello_messages = []
         self.header_size = 0
@@ -127,10 +128,12 @@ class AbstractConnection(Generic[Node]):
         logger.log(level, message, *args, **kwargs)
 
     def log_trace(self, message, *args, **kwargs):
-        self._log_message(LogLevel.TRACE, message, *args, **kwargs)
+        if logger.isEnabledFor(LogLevel.TRACE):
+            self._log_message(LogLevel.TRACE, message, *args, **kwargs)
 
     def log_debug(self, message, *args, **kwargs):
-        self._log_message(LogLevel.DEBUG, message, *args, **kwargs)
+        if logger.isEnabledFor(LogLevel.DEBUG):
+            self._log_message(LogLevel.DEBUG, message, *args, **kwargs)
 
     def log_info(self, message, *args, **kwargs):
         self._log_message(LogLevel.INFO, message, *args, **kwargs)
@@ -158,6 +161,8 @@ class AbstractConnection(Generic[Node]):
 
     def on_connection_established(self):
         if not self.is_active():
+            self.state |= ConnectionState.HELLO_RECVD
+            self.state |= ConnectionState.HELLO_ACKD
             self.state |= ConnectionState.ESTABLISHED
             self.log_info("Connection established.")
 
@@ -453,6 +458,10 @@ class AbstractConnection(Generic[Node]):
         """
         if self.can_send_pings and self.is_alive():
             self.enqueue_msg(self.ping_message)
+
+            if self.pong_timeout_enabled:
+                self.schedule_pong_timeout()
+
             return self.ping_interval_s
         return constants.CANCEL_ALARMS
 
@@ -493,7 +502,7 @@ class AbstractConnection(Generic[Node]):
         self.enqueue_msg(self.pong_message)
 
     def msg_pong(self, _msg):
-        pass
+        self.cancel_pong_timeout()
 
     def mark_for_close(self, should_retry: Optional[bool] = None):
         """
@@ -628,10 +637,11 @@ class AbstractConnection(Generic[Node]):
         self.format_connection_desc = "{} - {}".format(self.peer_desc, _short_connection_type)
 
     def _pong_msg_timeout(self):
-        self.log_info("Connection appears to be broken. Peer did not reply to PING message within allocated time. "
-                      "Closing connection.")
-        self.mark_for_close()
-        self.pong_timeout_alarm_id = None
+        if self.is_alive():
+            self.log_info("Connection appears to be broken. Peer did not reply to PING message within allocated time. "
+                          "Closing connection.")
+            self.mark_for_close()
+            self.pong_timeout_alarm_id = None
 
     def _report_bad_message(self):
         """
