@@ -4,8 +4,14 @@ from bxcommon.utils.buffers.input_buffer import InputBuffer
 
 class DefaultMessageValidator(AbstractMessageValidator):
 
-    def validate(self, is_full_msg: bool, msg_type: str, header_len: int, payload_len: int,
-                 input_buffer: InputBuffer) -> None:
+    def validate(
+        self,
+        is_full_msg: bool,
+        msg_type: str,
+        header_len: int,
+        payload_len: int,
+        input_buffer: InputBuffer
+    ) -> None:
         """
         Validates message payload length.
         Throws MessageValidationError is message is not valid
@@ -16,4 +22,3 @@ class DefaultMessageValidator(AbstractMessageValidator):
         :param payload_len: message payload length
         :param input_buffer: input buffer
         """
-        pass
\ No newline at end of file
