@@ -1,9 +1,8 @@
 import asyncio
 import gc
 import sys
-import argparse
 
-from typing import Iterable, Optional, Type, Callable, List, Union
+from typing import Iterable, Optional, Type, Callable, List
 
 import uvloop
 
@@ -14,7 +13,8 @@ from bxcommon.models.node_type import NodeType
 from bxcommon.network.node_event_loop import NodeEventLoop
 from bxcommon.services import sdn_http_service
 from bxcommon.utils import cli, model_loader, config, node_cache
-from bxcommon.utils.cli import CommonOpts
+from bxcommon.common_opts import CommonOpts
+from bxcommon.utils.init_task import AbstractInitTask
 from bxutils import log_messages
 from bxutils import logging
 from bxutils.logging import log_config, LoggerConfig, gc_logger
@@ -24,6 +24,8 @@ from bxutils.ssl import ssl_serializer
 from bxutils.ssl.data import ssl_data_factory
 from bxutils.ssl.ssl_certificate_type import SSLCertificateType
 
+
+OptsType = CommonOpts
 logger = logging.get_logger(__name__)
 
 LOGGER_NAMES = ["bxcommon", "bxutils"]
@@ -36,6 +38,36 @@ asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())  # pyre-ignore
 asyncio.set_event_loop(uvloop.new_event_loop())
 
 
+class SetNetworkInfo(AbstractInitTask):
+    def action(self, opts: OptsType, node_ssl_service) -> None:
+        cli.set_blockchain_networks_info(opts)
+        cli.parse_blockchain_opts(opts, opts.node_type)
+
+
+class SetNodeModel(AbstractInitTask):
+    def action(self, opts: OptsType, node_ssl_service) -> None:
+        node_model = None
+        if opts.node_id:
+            # Test network, get pre-configured peers from the SDN.
+            node_model = sdn_http_service.fetch_node_attributes(opts.node_id)
+
+        if not node_model:
+            node_model = register_node(opts, node_ssl_service)
+
+        if node_model.cert is not None:
+            private_cert = ssl_serializer.deserialize_cert(node_model.cert)
+            node_ssl_service.blocking_store_node_certificate(private_cert)
+            ssl_context = node_ssl_service.create_ssl_context(
+                SSLCertificateType.PRIVATE
+            )
+            sdn_http_service.reset_pool(ssl_context)
+
+        # Add opts from SDN, but don't overwrite CLI args
+        for key, val in node_model.__dict__.items():
+            if opts.__dict__.get(key) is None:
+                opts.__dict__[key] = val
+
+
 def default_ssl_service_factory(
     node_type: NodeType, ca_cert_url: str, private_ssl_base_url: str, data_dir: str
 ) -> NodeSSLService:
@@ -50,15 +82,17 @@ def default_ssl_service_factory(
 
 def run_node(
     process_id_file_path: str,
-    opts: Union[CommonOpts, argparse.Namespace],
+    opts: OptsType,
     get_node_class: Callable[[], Type[AbstractNode]],
     node_type: NodeType,
     logger_names: Optional[Iterable[str]] = tuple(LOGGER_NAMES),
     ssl_service_factory: Callable[
         [NodeType, str, str, str], NodeSSLService
     ] = default_ssl_service_factory,
-    third_party_loggers: Optional[List[LoggerConfig]] = None
+    third_party_loggers: Optional[List[LoggerConfig]] = None,
+    node_init_tasks: Optional[List[AbstractInitTask]] = None,
 ) -> None:
+
     if third_party_loggers is None:
         third_party_loggers = THIRD_PARTY_LOGGERS
     opts.logger_names = logger_names
@@ -74,8 +108,11 @@ def run_node(
         fluentd_queue_size=opts.log_fluentd_queue_size,
         third_party_loggers=third_party_loggers,
         fluent_log_level=opts.log_level_fluentd,
-        stdout_log_level=opts.log_level_stdout
+        stdout_log_level=opts.log_level_stdout,
     )
+    if node_init_tasks is None:
+        node_init_tasks = []
+
     startup_param = sys.argv[1:]
     logger.info("Startup Parameters are: {}", " ".join(startup_param))
 
@@ -93,8 +130,17 @@ def run_node(
                 "Initialized task thread pool parallelism degree to {}.",
                 task_pool_proxy.get_pool_size(),
             )
+
+        node_init_tasks.append(
+            SetNodeModel(SetNetworkInfo(*node_init_tasks))
+        )
+
         _run_node(
-            opts, get_node_class, node_type, ssl_service_factory=ssl_service_factory
+            opts,
+            get_node_class,
+            node_type,
+            node_init_tasks=node_init_tasks,
+            ssl_service_factory=ssl_service_factory,
         )
     except TerminationError:
         logger.fatal("Node terminated")
@@ -105,10 +151,12 @@ def run_node(
             handler.close()
 
 
-def register_node(opts: Union[CommonOpts, argparse.Namespace], node_ssl_service: NodeSSLService) -> NodeModel:
+def register_node(opts: OptsType, node_ssl_service: NodeSSLService) -> NodeModel:
     temp_node_model = model_loader.load_model(NodeModel, opts.__dict__)
     if node_ssl_service.should_renew_node_certificate():
-        temp_node_model.csr = ssl_serializer.serialize_csr(node_ssl_service.create_csr())
+        temp_node_model.csr = ssl_serializer.serialize_csr(
+            node_ssl_service.create_csr()
+        )
 
     try:
         node_model = sdn_http_service.register_node(temp_node_model)
@@ -139,19 +187,16 @@ def register_node(opts: Union[CommonOpts, argparse.Namespace], node_ssl_service:
 
 
 def _run_node(
-    opts: Union[CommonOpts, argparse.Namespace],
+    opts: OptsType,
     get_node_class,
     node_type,
+    node_init_tasks: List[AbstractInitTask],
     ssl_service_factory: Callable[
         [NodeType, str, str, str], NodeSSLService
     ] = default_ssl_service_factory,
 ) -> None:
 
-    node_model = None
-    if opts.node_id:
-        # Test network, get pre-configured peers from the SDN.
-        node_model = sdn_http_service.fetch_node_attributes(opts.node_id)
-
+    opts.node_type = node_type
     node_ssl_service = _init_ssl_service(
         node_type,
         opts.ca_cert_url,
@@ -160,43 +205,16 @@ def _run_node(
         ssl_service_factory=ssl_service_factory,
     )
 
-    account_id = node_ssl_service.get_account_id()
-    if account_id:
-        # TODO: use local cache for account_model
-        account_model = sdn_http_service.fetch_account_model(account_id)
-        if account_model:
-            set_account_options = getattr(opts, "set_account_options", None)
-            if set_account_options is not None:
-                set_account_options(account_model)
-
-    validate_network_opts = getattr(opts, "validate_network_opts", None)
-    if validate_network_opts is not None:
-        validate_network_opts()
-
-    cli.set_blockchain_networks_info(opts)
-    cli.parse_blockchain_opts(opts, node_type)
-
-    if not node_model:
-        opts.node_type = node_type
-        node_model = register_node(opts, node_ssl_service)
-
-    if node_model.cert is not None:
-        private_cert = ssl_serializer.deserialize_cert(node_model.cert)
-        node_ssl_service.blocking_store_node_certificate(private_cert)
-        ssl_context = node_ssl_service.create_ssl_context(SSLCertificateType.PRIVATE)
-        sdn_http_service.reset_pool(ssl_context)
-
-    # Add opts from SDN, but don't overwrite CLI args
-    for key, val in node_model.__dict__.items():
-        if opts.__dict__.get(key) is None:
-            opts.__dict__[key] = val
+    assert all(
+        task(opts, node_ssl_service)
+        for task in sorted(node_init_tasks, key=lambda x: x.order)
+    )
 
     if not hasattr(opts, "outbound_peers"):
         opts.__dict__["outbound_peers"] = []
 
     logger.debug({"type": "node_init", "data": opts})
 
-
     # Start main loop
     node = get_node_class()(opts, node_ssl_service)
     log_config.set_instance(node.opts.node_id)
@@ -216,7 +234,9 @@ def _init_ssl_service(
         [NodeType, str, str, str], NodeSSLService
     ] = default_ssl_service_factory,
 ) -> NodeSSLService:
-    node_ssl_service = ssl_service_factory(node_type, ca_cert_url, private_ssl_base_url, data_dir)
+    node_ssl_service = ssl_service_factory(
+        node_type, ca_cert_url, private_ssl_base_url, data_dir
+    )
     node_ssl_service.blocking_load()
 
     if node_ssl_service.has_valid_certificate(SSLCertificateType.PRIVATE):
@@ -228,6 +248,6 @@ def _init_ssl_service(
     return node_ssl_service
 
 
-def _verify_environment():
+def _verify_environment() -> None:
     if sys.version.startswith("3.6."):
         logger.warning(log_messages.DETECTED_PYTHON3_6)
