@@ -25,7 +25,7 @@ from bxcommon.utils.stats.transaction_stat_event_type import TransactionStatEven
 from bxcommon.utils.stats.transaction_statistics_service import tx_stats
 from bxgateway import log_messages, gateway_constants
 from bxgateway.feed.new_transaction_feed import NewTransactionFeed, \
-    TransactionFeedEntry
+    RawTransactionFeedEntry
 from bxgateway.utils.logging.status import status_log
 from bxgateway.utils.stats.gateway_bdn_performance_stats_service import gateway_bdn_performance_stats_service, \
     GatewayBdnPerformanceStatInterval
@@ -323,13 +323,15 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
             )
 
     def send_bdn_performance_stats(self, bdn_stats_interval: GatewayBdnPerformanceStatInterval):
+        memory_utilization_mb = int(memory_utils.get_app_memory_usage() / constants.BYTE_TO_MB)
         msg_to_send = BdnPerformanceStatsMessage(
             bdn_stats_interval.start_time,
             bdn_stats_interval.end_time,
             bdn_stats_interval.new_blocks_received_from_blockchain_node,
             bdn_stats_interval.new_blocks_received_from_bdn,
             bdn_stats_interval.new_tx_received_from_blockchain_node,
-            bdn_stats_interval.new_tx_received_from_bdn
+            bdn_stats_interval.new_tx_received_from_bdn,
+            memory_utilization_mb
         )
         self.enqueue_msg(msg_to_send)
 
@@ -338,11 +340,6 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
 
     def msg_notify(self, msg: NotificationMessage) -> None:
         if msg.notification_code() == NotificationCode.QUOTA_FILL_STATUS:
-            seconds_since_last_quota_notification = time.time() - self.node.last_quota_level_notification_time
-            if seconds_since_last_quota_notification < gateway_constants.QUOTA_NOTIFICATION_IGNORE_REPEAT_WINDOW_S:
-                return
-
-            self.node.last_quota_level_notification_time = time.time()
             args_list = msg.raw_message().split(",")
             entity_type = EntityType(int(args_list[1]))
             quota_level = int(args_list[0])
@@ -366,5 +363,5 @@ class AbstractRelayConnection(InternalNodeConnection["AbstractGatewayNode"]):
     ) -> None:
         self.node.feed_manager.publish_to_feed(
             NewTransactionFeed.NAME,
-            TransactionFeedEntry(tx_hash, tx_contents)
+            RawTransactionFeedEntry(tx_hash, tx_contents)
         )
