@@ -23,6 +23,8 @@ from bxgateway.connections.eth.eth_node_discovery_connection import EthNodeDisco
 from bxgateway.connections.eth.eth_relay_connection import EthRelayConnection
 from bxgateway.connections.eth.eth_remote_connection import EthRemoteConnection
 from bxgateway.connections.gateway_connection import GatewayConnection
+from bxgateway.feed.eth.eth_new_transaction_feed import EthNewTransactionFeed
+from bxgateway.feed.eth.eth_pending_transaction_feed import EthPendingTransactionFeed
 from bxgateway.messages.eth import eth_message_converter_factory as converter_factory
 from bxgateway.messages.eth.new_block_parts import NewBlockParts
 from bxgateway.rpc.external.eth_ws_subscriber import EthWsSubscriber
@@ -33,9 +35,9 @@ from bxgateway.services.eth.eth_normal_block_cleanup_service import EthNormalBlo
 from bxgateway.services.push_block_queuing_service import PushBlockQueuingService
 from bxgateway.testing.eth_lossy_relay_connection import EthLossyRelayConnection
 from bxgateway.testing.test_modes import TestModes
-from bxgateway.utils.eth import crypto_utils
+from bxcommon.utils.blockchain_utils.eth import crypto_utils, eth_common_constants
 from bxgateway.utils.stats.eth.eth_gateway_stats_service import eth_gateway_stats_service
-from bxgateway import log_messages, eth_constants
+from bxgateway import log_messages
 from bxutils import logging
 from bxutils.services.node_ssl_service import NodeSSLService
 
@@ -66,7 +68,7 @@ class EthGatewayNode(AbstractGatewayNode):
     }
 
     def __init__(self, opts, node_ssl_service: NodeSSLService):
-        super(EthGatewayNode, self).__init__(opts, node_ssl_service, eth_constants.TRACKED_BLOCK_CLEANUP_INTERVAL_S)
+        super(EthGatewayNode, self).__init__(opts, node_ssl_service, eth_common_constants.TRACKED_BLOCK_CLEANUP_INTERVAL_S)
 
         self._node_public_key = None
         self._remote_public_key = None
@@ -87,7 +89,7 @@ class EthGatewayNode(AbstractGatewayNode):
         self.block_queuing_service: EthBlockQueuingService = EthBlockQueuingService(self)
 
         # List of know total difficulties, tuples of values (block hash, total difficulty)
-        self._last_known_difficulties = deque(maxlen=eth_constants.LAST_KNOWN_TOTAL_DIFFICULTIES_MAX_COUNT)
+        self._last_known_difficulties = deque(maxlen=eth_common_constants.LAST_KNOWN_TOTAL_DIFFICULTIES_MAX_COUNT)
 
         # queue of the block hashes requested from remote blockchain node during sync
         self._requested_remote_blocks_queue = deque()
@@ -126,7 +128,7 @@ class EthGatewayNode(AbstractGatewayNode):
     ) -> AbstractGatewayBlockchainConnection:
         return EthRemoteConnection(socket_connection, self)
 
-    def build_block_queuing_service(self) -> PushBlockQueuingService:
+    def build_block_queuing_service(self) -> EthBlockQueuingService:
         return EthBlockQueuingService(self)
 
     def build_block_cleanup_service(self) -> AbstractBlockCleanupService:
@@ -320,6 +322,10 @@ class EthGatewayNode(AbstractGatewayNode):
         eth_gateway_stats_service.set_node(self)
         self.alarm_queue.register_alarm(eth_gateway_stats_service.interval, eth_gateway_stats_service.flush_info)
 
+    def init_live_feeds(self) -> None:
+        self.feed_manager.register_feed(EthNewTransactionFeed())
+        self.feed_manager.register_feed(EthPendingTransactionFeed(self.alarm_queue))
+
     def get_enode(self):
         return \
             f"enode://{convert.bytes_to_hex(self.get_public_key())}@{self.opts.external_ip}:{self.opts.non_ssl_port}"
@@ -362,6 +368,6 @@ class EthGatewayNode(AbstractGatewayNode):
 
         return self.DISCONNECT_REASON_TO_INSTRUCTION[reason]
 
-    def on_new_subscriber(self) -> None:
+    def on_new_subscriber_request(self) -> None:
         if self.opts.eth_ws_uri and not self.eth_ws_subscriber.running:
             asyncio.create_task(self.eth_ws_subscriber.revive())
