@@ -1,15 +1,14 @@
 import typing
-from typing import Iterable, TYPE_CHECKING
 from abc import abstractmethod
-
-from bxutils import logging
-from bxutils.logging.log_record_type import LogRecordType
+from typing import Iterable, TYPE_CHECKING
 
 from bxcommon.services.transaction_service import TransactionService
+from bxcommon.utils import convert
 from bxcommon.utils.object_hash import Sha256Hash
-
 from bxgateway.messages.eth.protocol.new_block_eth_protocol_message import NewBlockEthProtocolMessage
 from bxgateway.services.abstract_block_cleanup_service import AbstractBlockCleanupService
+from bxutils import logging
+from bxutils.logging.log_record_type import LogRecordType
 
 if TYPE_CHECKING:
     from bxgateway.connections.eth.eth_gateway_node import EthGatewayNode
@@ -32,9 +31,9 @@ class AbstractEthBlockCleanupService(AbstractBlockCleanupService):
         super(AbstractEthBlockCleanupService, self).__init__(node=node, network_num=network_num)
 
     def clean_block_transactions(
-            self,
-            block_msg: NewBlockEthProtocolMessage,
-            transaction_service: TransactionService
+        self,
+        block_msg: NewBlockEthProtocolMessage,
+        transaction_service: TransactionService
     ) -> None:
         block_hash = block_msg.block_hash()
         transactions_list = block_msg.txns()
@@ -45,24 +44,32 @@ class AbstractEthBlockCleanupService(AbstractBlockCleanupService):
         )
 
     def clean_block_transactions_from_block_queue(
-            self,
-            block_hash: Sha256Hash
+        self,
+        block_hash: Sha256Hash
     ) -> None:
-        block_body = self.node.block_queuing_service.get_block_body_from_message(block_hash)
-        transactions_hashes = block_body.get_block_transaction_hashes(0)
-        self.node.block_cleanup_service.clean_block_transactions_by_block_components(
-            transaction_service=self.node.get_tx_service(),
-            block_hash=block_hash,
-            transactions_list=transactions_hashes
-        )
+        try:
+            block_body = self.node.block_queuing_service.get_block_body_from_message(block_hash)
+            transactions_hashes = block_body.get_block_transaction_hashes(0)
+            self.node.block_cleanup_service.clean_block_transactions_by_block_components(
+                transaction_service=self.node.get_tx_service(),
+                block_hash=block_hash,
+                transactions_list=transactions_hashes
+            )
+        except Exception as error:
+            logger.error("clean_block_transactions_from_block_queue operation for block {} failed with error {}.",
+                         block_hash, error)
+            block_body_parts = self.node.block_queuing_service.get_block_parts(block_hash)
+            logger.debug("Failed block body bytes: {}",
+                         "Empty" if block_body_parts is None
+                         else convert.bytes_to_hex(block_body_parts.block_body_bytes))
 
     @abstractmethod
     def clean_block_transactions_by_block_components(
-            self,
-            block_hash: Sha256Hash,
-            transactions_list: Iterable[Sha256Hash],
-            transaction_service: TransactionService
-         ) -> None:
+        self,
+        block_hash: Sha256Hash,
+        transactions_list: Iterable[Sha256Hash],
+        transaction_service: TransactionService
+    ) -> None:
         pass
 
     def _request_block(self, block_hash: Sha256Hash):
